Crate lutra_bin

Crate lutra_bin 

Re-exports

pub use error::Error;
pub use error::Result;
pub use layout::Layout;
pub use reader::ArrayReader;
pub use reader::ReaderExt;
pub use reader::TupleReader;
pub use bytes;

Modules

boxed
The Box<T> type for heap allocation.
br
collections
Collection types.
error
ident
Common utils for Lutra identifiers
ir
layout
reader
rr
string
A UTF-8–encoded, growable string.
typed_data
Typed data format
vec
A contiguous growable array type with heap-allocated contents, written Vec<T>.

Macros

vec
Creates a Vec containing the arguments.

Structs

ReversePointer
Pointer to a location where an offset should be written to.
Shape
Structural shape of a value.
TableCell
TabularReader
Utility for iterating over arbitrary data in tabular manner (as rows and columns).

Enums

Value
Generic Lutra value object

Traits

Decode
Encode
ValueVisitor
Visitor

Functions

decode_enum_head
encode_enum_head_padding
encode_enum_head_tag
get_shape
Extract the Shape of data without decoding individual values.
print_source