pub enum Program {
SqlPostgres(Box<SqlProgram>),
SqlDuckDB(Box<SqlProgram>),
BytecodeLt(Program),
}Variants
Implementations
Sourceimpl Program
impl Program
Sourcepub fn is_sql_postgres(&self) -> bool
pub fn is_sql_postgres(&self) -> bool
Returns true if this is a Program::SqlPostgres, otherwise false
Sourcepub fn as_sql_postgres_mut(&mut self) -> Option<&mut Box<SqlProgram>>
pub fn as_sql_postgres_mut(&mut self) -> Option<&mut Box<SqlProgram>>
Optionally returns mutable references to the inner fields if this is a Program::SqlPostgres, otherwise None
Sourcepub fn as_sql_postgres(&self) -> Option<&Box<SqlProgram>>
pub fn as_sql_postgres(&self) -> Option<&Box<SqlProgram>>
Optionally returns references to the inner fields if this is a Program::SqlPostgres, otherwise None
Sourcepub fn into_sql_postgres(self) -> Result<Box<SqlProgram>, Self>
pub fn into_sql_postgres(self) -> Result<Box<SqlProgram>, Self>
Returns the inner fields if this is a Program::SqlPostgres, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_sql_duck_db(&self) -> bool
pub fn is_sql_duck_db(&self) -> bool
Returns true if this is a Program::SqlDuckDB, otherwise false
Sourcepub fn as_sql_duck_db_mut(&mut self) -> Option<&mut Box<SqlProgram>>
pub fn as_sql_duck_db_mut(&mut self) -> Option<&mut Box<SqlProgram>>
Optionally returns mutable references to the inner fields if this is a Program::SqlDuckDB, otherwise None
Sourcepub fn as_sql_duck_db(&self) -> Option<&Box<SqlProgram>>
pub fn as_sql_duck_db(&self) -> Option<&Box<SqlProgram>>
Optionally returns references to the inner fields if this is a Program::SqlDuckDB, otherwise None
Sourcepub fn into_sql_duck_db(self) -> Result<Box<SqlProgram>, Self>
pub fn into_sql_duck_db(self) -> Result<Box<SqlProgram>, Self>
Returns the inner fields if this is a Program::SqlDuckDB, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_bytecode_lt(&self) -> bool
pub fn is_bytecode_lt(&self) -> bool
Returns true if this is a Program::BytecodeLt, otherwise false
Sourcepub fn as_bytecode_lt_mut(&mut self) -> Option<&mut Program>
pub fn as_bytecode_lt_mut(&mut self) -> Option<&mut Program>
Optionally returns mutable references to the inner fields if this is a Program::BytecodeLt, otherwise None
Sourcepub fn as_bytecode_lt(&self) -> Option<&Program>
pub fn as_bytecode_lt(&self) -> Option<&Program>
Optionally returns references to the inner fields if this is a Program::BytecodeLt, otherwise None
Sourcepub fn into_bytecode_lt(self) -> Result<Program, Self>
pub fn into_bytecode_lt(self) -> Result<Program, Self>
Returns the inner fields if this is a Program::BytecodeLt, otherwise returns back the enum in the Err case of the result