Re-exports
pub use error::Error;pub use error::Result;pub use layout::Layout;pub use reader::ArrayReader;pub use reader::ReaderExt;pub use reader::TupleReader;pub use bytes;
Modules
- boxed
- The
Box<T>type for heap allocation. - br
- collections
- Collection types.
- error
- ident
- Common utils for Lutra identifiers
- ir
- layout
- reader
- rr
- string
- A UTF-8–encoded, growable string.
- typed_
data - Typed data format
- vec
- A contiguous growable array type with heap-allocated contents, written
Vec<T>.
Macros
Structs
- Reverse
Pointer - Pointer to a location where an offset should be written to.
- Shape
- Structural shape of a value.
- Table
Cell - Tabular
Reader - Utility for iterating over arbitrary data in tabular manner (as rows and columns).
Enums
- Value
- Generic Lutra value object
Traits
Functions
- decode_
enum_ head - encode_
enum_ head_ padding - encode_
enum_ head_ tag - get_
shape - Extract the
Shapeofdatawithout decoding individual values. - print_
source