Program

Enum Program 

pub enum Program {
    SqlPostgres(Box<SqlProgram>),
    SqlDuckDB(Box<SqlProgram>),
    BytecodeLt(Program),
}

Variants



SqlPostgres(Box<SqlProgram>)



SqlDuckDB(Box<SqlProgram>)



BytecodeLt(Program)

Implementations

Source

impl Program

pub fn is_sql_postgres(&self) -> bool

Returns true if this is a Program::SqlPostgres, otherwise false

pub fn as_sql_postgres_mut(&mut self) -> Option<&mut Box<SqlProgram>>

Optionally returns mutable references to the inner fields if this is a Program::SqlPostgres, otherwise None

pub fn as_sql_postgres(&self) -> Option<&Box<SqlProgram>>

Optionally returns references to the inner fields if this is a Program::SqlPostgres, otherwise None

pub fn into_sql_postgres(self) -> Result<Box<SqlProgram>, Self>

Returns the inner fields if this is a Program::SqlPostgres, otherwise returns back the enum in the Err case of the result

pub fn is_sql_duck_db(&self) -> bool

Returns true if this is a Program::SqlDuckDB, otherwise false

pub fn as_sql_duck_db_mut(&mut self) -> Option<&mut Box<SqlProgram>>

Optionally returns mutable references to the inner fields if this is a Program::SqlDuckDB, otherwise None

pub fn as_sql_duck_db(&self) -> Option<&Box<SqlProgram>>

Optionally returns references to the inner fields if this is a Program::SqlDuckDB, otherwise None

pub fn into_sql_duck_db(self) -> Result<Box<SqlProgram>, Self>

Returns the inner fields if this is a Program::SqlDuckDB, otherwise returns back the enum in the Err case of the result

pub fn is_bytecode_lt(&self) -> bool

Returns true if this is a Program::BytecodeLt, otherwise false

pub fn as_bytecode_lt_mut(&mut self) -> Option<&mut Program>

Optionally returns mutable references to the inner fields if this is a Program::BytecodeLt, otherwise None

pub fn as_bytecode_lt(&self) -> Option<&Program>

Optionally returns references to the inner fields if this is a Program::BytecodeLt, otherwise None

pub fn into_bytecode_lt(self) -> Result<Program, Self>

Returns the inner fields if this is a Program::BytecodeLt, otherwise returns back the enum in the Err case of the result